==> xwpe_1.4.2.orig.tar.gz: xwpe-1.4.2.orig/keys.h <==
/* keys.h						  */
/* Copyright (C) 1993 Fred Kruse                          */
/* This is free software; you can redistribute it and/or  */
/* modify it under the terms of the                       */
/* GNU General Public License, see the file COPYING.      */

/*  		Definition of Keyboard-Keys		*/

#define CtrlA 1
#define CtrlB 2
#define CtrlC 3
#define CtrlD 4
#define CtrlE 5
#define CtrlF 6
#define CtrlG 7
#define CtrlH 8
#define CtrlI 9
#define CtrlJ 10
#define CtrlK 11
#define CtrlL 12
#define CtrlM 13
#define CtrlN 14
#define CtrlO 15
#define CtrlP 16
#define CtrlQ 17
#define CtrlR 18
#define CtrlS 19
#define CtrlT 20
#define CtrlU 21
#define CtrlV 22
#define CtrlW 23
#define CtrlX 24
#define CtrlY 25
#define CtrlZ 26

#define AltA 285
#define AltB 303
#define AltC 301
#define AltD 287
#define AltE 273
#define AltF 288
#define AltG 289
#define AltH 290
#define AltI 278
#define AltJ 291
#define AltK 292
#define AltL 293
#define AltM 305
#define AltN 304
#define AltO 279
#define AltP 280
#define AltQ 271
#define AltR 274
#define AltS 286
#define AltT 275
#define AltU 277
#define AltV 302
#define AltW 272
#define AltX 300
#define AltY 299
#define AltZ 276
#define Alt1 375
#define Alt2 376
#define Alt3 377
#define Alt4 378
#define Alt5 379
#define Alt6 380
#define Alt7 381
#define Alt8 382
#define Alt9 383
#define Alt0 384
#define AltBS 385
#define AltBl 386
#define AltSYS 298
#define AltEin 953
#define AltDel 954

#define CUP 327
#define CDO 335
#define CLE 330
#define CRI 332
#define CCLE 370
#define CCRI 371
#define EINFG 337
#define ENTF 338
#define POS1 326
#define ENDE 334
#define BUP 328               
#define BDO 336
#define CBUP 387
#define CBDO 373
#define CPS1 374
#define CEND 372
#define CtrlDel 852
#define CtrlEin 851
#define CENTF   852
#define CEINFG  851
#define ShiftDel 850
#define ShiftEin 849

#define F1 314
#define F2 315
#define F3 316
#define F4 317
#define F5 318
#define F6 319
#define F7 320
#define F8 321
#define F9 322
#define F10 323

#define AF1 359
#define AF2 360
#define AF3 361
#define AF4 362
#define AF5 363
#define AF6 364
#define AF7 365
#define AF8 366
#define AF9 367
#define AF10 368

#define SF1 826
#define SF2 827
#define SF3 828
#define SF4 829
#define SF5 830
#define SF6 831
#define SF7 832
#define SF8 833
#define SF9 834
#define SF10 835
#define SABS 897

#define CF1 349
#define CF2 350
#define CF3 351
#define CF4 352
#define CF5 353
#define CF6 354
#define CF7 355
#define CF8 357
#define CF9 358
#define CF10 951


#define HBG CtrlA	/*  Button-Anfang  */
#define HFB CtrlG	/*  Button-Man-Page-Anfang  */
#define HNF CtrlC	/*  Button mit Verweis auf Datei   */
#define HED CtrlE	/*  Ende Marke   */
#define HHD CtrlB	/*  Anfang-Ueberschrift   */
#define HFE CtrlF	/*  Seitenende   */
#define HBS CtrlH	/*  Backspace (Man-Pages)  */
#define HBB CtrlO	/*  Markierung-Beginn  */

#define MBKEY -100

==> xwpe_1.5.22a.orig.tar.gz: xwpe-1.5.22a.orig/keys.h <==
/* keys.h						  */
/* Copyright (C) 1993 Fred Kruse                          */
/* This is free software; you can redistribute it and/or  */
/* modify it under the terms of the                       */
/* GNU General Public License, see the file COPYING.      */

/*  		Definition of Keyboard-Keys		*/

#define CtrlA 1
#define CtrlB 2
#define CtrlC 3
#define CtrlD 4
#define CtrlE 5
#define CtrlF 6
#define CtrlG 7
#define CtrlH 8
#define CtrlI 9
#define CtrlJ 10
#define CtrlK 11
#define CtrlL 12
#define CtrlM 13
#define CtrlN 14
#define CtrlO 15
#define CtrlP 16
#define CtrlQ 17
#define CtrlR 18
#define CtrlS 19
#define CtrlT 20
#define CtrlU 21
#define CtrlV 22
#define CtrlW 23
#define CtrlX 24
#define CtrlY 25
#define CtrlZ 26

#define AltA 285
#define AltB 303
#define AltC 301
#define AltD 287
#define AltE 273
#define AltF 288
#define AltG 289
#define AltH 290
#define AltI 278
#define AltJ 291
#define AltK 292
#define AltL 293
#define AltM 305
#define AltN 304
#define AltO 279
#define AltP 280
#define AltQ 271
#define AltR 274
#define AltS 286
#define AltT 275
#define AltU 277
#define AltV 302
#define AltW 272
#define AltX 300
#define AltY 299
#define AltZ 276
#define Alt1 375
#define Alt2 376
#define Alt3 377
#define Alt4 378
#define Alt5 379
#define Alt6 380
#define Alt7 381
#define Alt8 382
#define Alt9 383
#define Alt0 384
#define AltBS 385
#define AltBl 386
#define AltSYS 298
#define AltEin 953
#define AltDel 954

#define CUP 327
#define CDO 335
#define CLE 330
#define CRI 332
#define CCLE 370
#define CCRI 371
#define EINFG 337
#define ENTF 338
#define POS1 326
#define ENDE 334
#define BUP 328               
#define BDO 336
#define CBUP 387
#define CBDO 373
#define CPS1 374
#define CEND 372
#define CtrlDel 852
#define CtrlEin 851
#define CENTF   852
#define CEINFG  851
#define ShiftDel 850
#define ShiftEin 849

#define F1 314
#define F2 315
#define F3 316
#define F4 317
#define F5 318
#define F6 319
#define F7 320
#define F8 321
#define F9 322
#define F10 323

#define AF1 359
#define AF2 360
#define AF3 361
#define AF4 362
#define AF5 363
#define AF6 364
#define AF7 365
#define AF8 366
#define AF9 367
#define AF10 368

#define SF1 826
#define SF2 827
#define SF3 828
#define SF4 829
#define SF5 830
#define SF6 831
#define SF7 832
#define SF8 833
#define SF9 834
#define SF10 835
#define SABS 897

#define CF1 349
#define CF2 350
#define CF3 351
#define CF4 352
#define CF5 353
#define CF6 354
#define CF7 355
#define CF8 357
#define CF9 358
#define CF10 951


#define HBG CtrlA	/*  Button start  */
#define HFB CtrlG	/*  Button-Man-Page start  */
#define HNF CtrlC	/*  Button with link to file   */
#define HED CtrlE	/*  End Mark   */
#define HHD CtrlB	/*  start headline   */
#define HFE CtrlF	/*  end of page   */
#define HBS CtrlH	/*  Backspace (Man-Pages)  */
#define HBB CtrlO	/*  start highlight  */

#define MBKEY -100
